from datetime import time


class BaseJob(object):
    """if you want to create a new job just extend this class"""
    source = None
    destination = None
    content = None
    status_change = {}
    _status = None

    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self.status_change.update({value: time()})
        self._status = value

class PredictionContent(object):
    """the content class for Prediction Job"""
    args = {}

class PredictionJob(BaseJob):
    """the particular job for Deep Learning Prediction"""
    content =  PredictionContent()


from redis import Redis
from Qjob import BaseJob
from Qlist import LD,LW,LQ
conn = Redis(host='127.0.0.1',port='6379')

ld = LD(connection=conn)
lw = LW(connection=conn)
lq = LQ(connection=conn)

job = BaseJob()

lq.queue(job)
print(lq.get(0))
lq.pop_to(lw)
print(lw.get(0))
lw.pop_to(ld)
print(l.get(0))